==> worlds_raft-0.3.5.tar.gz: worlds_raft-0.3.5/src/worlds/raft/docs/en_Raft.md <==
# Raft

## Where is the options page?
The player options page for this game is located <a href="../player-options">here</a>. It contains all the options
you need to configure and export a config file.

## What does randomization do to this game?
All of the items from the Research Table, as well as all the note/blueprint/character pickups from story islands, are changed to location checks. Blueprint items themselves are never given when receiving a blueprint.

## What is the goal of Raft when randomized?
The goal remains the same: To complete the game by getting to the end of the game and finishing Utopia.

## Which items can be in another player's world?
All of the craftable items from the Research Table and Blueprints, as well as frequencies. Since there are more locations in Raft than there are items to receive, Resource Packs with basic earlygame materials and/or duplicate items may be added to the item pool (configurable).

## Which notable unlocks are not randomized?
Most of the story island quests (actions that unlock new areas on the island) remain unchanged. There are three exceptions: The Balboa Island Relay Station quest, the Caravan Island zipline parts quest, and the Caravan Island battery charger quest have all been changed to an Archipelago unlock, as the rewards from these are craftable items or frequencies.
Craftable items like the Machete are mixed into the Archipelago item pool, however quest items like Tape or Berries will function the same.
Decoration Packages are unchanged.

## What does another world's item look like in Raft?
Researches and pickups remain visually unchanged, regardless of what the unlock is.

## When the player receives an item, what happens?
A Raft notification will appear with the item information. The unlock will also appear in the chat. Unlocks that would normally give you the item (eg Zipline) will NOT give it to you, but must instead be crafted.

## Are there any limitations compared to vanilla Raft?
- Mods that add new researchable technologies, modify story islands, or give items like blueprints are likely incompatible with Raftipelago.
    - Some mods that add items that are always craftable (eg don't add them to the Research Table) may be compatible.
    - Mods that do not affect items, notes, blueprints, or story islands have a good chance of being compatible with Raftipelago
    - No mods have been comprehensively tested or verified to work with Raftipelago. Use at your own risk.

==> worlds_raft-0.3.6.tar.gz: worlds_raft-0.3.6/src/worlds/raft/docs/en_Raft.md <==
# Raft

## Where is the options page?
The player options page for this game is located <a href="../player-options">here</a>. It contains all the options
you need to configure and export a config file.

## What does randomization do to this game?
All of the items from the Research Table, as well as all the note/blueprint/character pickups from story islands, are changed to location checks. Blueprint items themselves are never given when receiving a blueprint.

## What is the goal of Raft when randomized?
The goal remains the same: To complete the game by getting to the end of the game and finishing Utopia.

## Which items can be in another player's world?
All of the craftable items from the Research Table and Blueprints, as well as frequencies. Since there are more locations in Raft than there are items to receive, Resource Packs with basic earlygame materials and/or duplicate items may be added to the item pool (configurable).

## Which notable unlocks are not randomized?
Most of the story island quests (actions that unlock new areas on the island) remain unchanged. There are three exceptions: The Balboa Island Relay Station quest, the Caravan Island zipline parts quest, and the Caravan Island battery charger quest have all been changed to a MultiworldGG unlock, as the rewards from these are craftable items or frequencies.
Craftable items like the Machete are mixed into the MultiworldGG item pool, however quest items like Tape or Berries will function the same.
Decoration Packages are unchanged.

## What does another world's item look like in Raft?
Researches and pickups remain visually unchanged, regardless of what the unlock is.

## When the player receives an item, what happens?
A Raft notification will appear with the item information. The unlock will also appear in the chat. Unlocks that would normally give you the item (eg Zipline) will NOT give it to you, but must instead be crafted.

## Are there any limitations compared to vanilla Raft?
- Mods that add new researchable technologies, modify story islands, or give items like blueprints are likely incompatible with Raftipelago.
    - Some mods that add items that are always craftable (eg don't add them to the Research Table) may be compatible.
    - Mods that do not affect items, notes, blueprints, or story islands have a good chance of being compatible with Raftipelago
    - No mods have been comprehensively tested or verified to work with Raftipelago. Use at your own risk.
